%% LRR solution for problem with noise
% INPUT:
%   X     - Data matrix, columns are samples.
%
%   D  -    number of landmarks
%
%   K  -    number of clusters
%
%   tau -    threshold for closed form solution of the LRR SC problem
%
%   Gt  -   correct clusters (ground truth)
%
%OUTPUT:
%
% idx   -  vector containing cluster indexes for each sample
%
function [  idx ] = lrr_SC( X, D, K, tau, Gt )

    %if method == 1
    thrs = 1/sqrt(tau);
    
    [U,Sig,V]=svdsecon(X,D);
    % err_svdsecon = norm(X-U*Sig*V')
    
    SS = diag(Sig);
    r = sum(SS>thrs);
    V = V(:,1:r);
    Sig = diag(1/sqrt(SS(1:r)));
    C = V*(eye(r)-(1/tau)*Sig)*V';
 
    %elseif method == 2
    %   C  = admm(X, beta_1, beta_2, mu_2, mu_3);
    %end
    
    % affinity matrix
    C = abs(C) + transpose(abs(C));
    
    tstart = tic;
    % spectral clustering of the affinity matrix
    DD = diag(1./sqrt(sum(C,2)));
    C = DD*C*DD;
    
    %display('SVD of the affinity matrix')
    % [U,S,V] = svd(C);
    
    [U,Sig,V]=svdsecon(C,K);
    %time_svdsecon=toc(tstart)
    % err_svdsecon = norm(X-U*Sig*V')
    V = U(:,1:K);
    V = normr(V);
    
    n = size(V,1);
    M = zeros(K,K,20);
    rand('state',123456789);
    for i=1:size(M,3)
        inds = false(n,1);
        while sum(inds)<K
            j = ceil(rand()*n);
            inds(j) = true;
        end
        M(:,:,i) = V(inds,:);
    end
    
    idx = kmeans(V,K,'emptyaction','singleton','Replicates',size(M,3),'start',M,'display','off');

end

